#!/usr/bin/env node
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// src/cli.ts
var import_commander = require("commander");

// src/main.ts
var import_path2 = __toESM(require("path"));
var glob = __toESM(require("glob"));
var import_fs = __toESM(require("fs"));

// src/util.ts
var import_vite = require("vite");
var import_path = __toESM(require("path"));
var regCustomProperty = /\s*-{2}[a-zA-F0-9-]+\s*:\s*[a-zA-Z0-9#\"\-\,\s\(\).]+\s*;\n*/g;
var getFinalOptions = async (options2) => {
  let viteConfig = null;
  if (options2.vite) {
    viteConfig = await (0, import_vite.resolveConfig)(
      {
        configFile: import_path.default.resolve(__dirname, "./vite.config.ts")
      },
      "build"
    );
  }
  return {
    include: options2.include || "**/*.?(css|scss|sass|less)",
    exclude: options2.exclude,
    output: options2.output || "./properties.ts",
    vite: !!options2,
    scss: getScssOptions(viteConfig),
    less: getLessOptions(viteConfig)
  };
};
var getScssOptions = (config) => {
  return config?.css?.preprocessorOptions?.scss;
};
var getLessOptions = (config) => {
  return config?.css?.preprocessorOptions?.less;
};
var toCamelCase = (target) => {
  return target.replace("--", "").replace(/^[A-Z]/, (m) => m.toLowerCase()).replace(/[-_ ./~ ]+([A-z0-9])/g, (m, $1) => $1.toUpperCase());
};

// src/main.ts
var _loadedSassPreprocessor;
var _loadedLessPreprocessor;
var main = async (options2) => {
  const finalOptions = await getFinalOptions(options2);
  const filePaths = glob.sync(finalOptions.include, {
    ignore: finalOptions.exclude
  });
  let customProperties = /* @__PURE__ */ new Map();
  for (const filePath of filePaths) {
    try {
      const buffer = import_fs.default.readFileSync(filePath);
      const fileContent = buffer.toString();
      let customPropertyWithValues = null;
      if (filePath.endsWith(".scss") || filePath.endsWith(".sass")) {
        customPropertyWithValues = sass(filePath, finalOptions);
      } else if (filePath.endsWith(".less")) {
        customPropertyWithValues = await less(
          filePath,
          fileContent,
          finalOptions
        );
      } else if (filePath.endsWith(".css")) {
        customPropertyWithValues = fileContent.match(regCustomProperty);
      }
      if (!customPropertyWithValues) {
        continue;
      }
      customPropertyWithValues.map((customPropertyWithValue) => {
        const [customPropertyKeyWithWhitespace, customPropertyValue] = customPropertyWithValue.split(":");
        const customPropertyKey = customPropertyKeyWithWhitespace.replaceAll(
          /[\s\n]*/g,
          ""
        );
        if (!customProperties.has(customPropertyKey)) {
          customProperties.set(customPropertyKey, customPropertyValue);
        }
      });
    } catch (e) {
      console.log("e :>> ", e);
    }
  }
  import_fs.default.writeFileSync(
    import_path2.default.resolve(finalOptions.output),
    generateOutputString(customProperties),
    {}
  );
};
var sass = (filePath, options2) => {
  const sass2 = loadSassPreprocessor();
  const result = sass2.renderSync({
    ...options2.scss,
    file: filePath,
    includePaths: ["node_modules"]
  });
  return result.css.toString().match(regCustomProperty);
};
var less = async (filePath, fileContent, options2) => {
  const less2 = loadLessPreprocessor();
  const result = await less2.render(fileContent, {
    ...options2.less,
    paths: [import_path2.default.dirname(filePath)]
  });
  return result.css.match(regCustomProperty);
};
var loadSassPreprocessor = () => {
  try {
    if (_loadedSassPreprocessor) {
      return _loadedSassPreprocessor;
    }
    const fallbackPaths = require.resolve.paths?.("sass") || [];
    const resolved = require.resolve("sass", {
      paths: [__dirname, ...fallbackPaths]
    });
    return _loadedSassPreprocessor = require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'sass' not found. Did you install it?`
    );
  }
};
var loadLessPreprocessor = () => {
  try {
    if (_loadedLessPreprocessor) {
      return _loadedLessPreprocessor;
    }
    const fallbackPaths = require.resolve.paths?.("less") || [];
    const resolved = require.resolve("less", {
      paths: [__dirname, ...fallbackPaths]
    });
    return _loadedLessPreprocessor = require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'less' not found. Did you install it?`
    );
  }
};
var generateOutputString = (customProperties) => {
  let outputString = "";
  for (const customProperty of customProperties) {
    outputString = `${outputString}/**
`;
    outputString = `${outputString} * ${customProperty[1].replaceAll(
      /[\n]*/g,
      ""
    )}
`;
    outputString = `${outputString} */
`;
    outputString = `${outputString}export const ${toCamelCase(
      customProperty[0]
    )} = "var(${customProperty[0]})"
`;
  }
  return outputString;
};

// src/cli.ts
import_commander.program.option("-o, --output <path>", "output path.").option("-i, --include <path>", "include path (glob pattern).").option("-e, --exclude <path>", "exclude path (glob pattern).").parse(process.argv);
var options = import_commander.program.opts();
main(options);
